@@ -12,7 +12,7 @@
 #############################################
 
 
- 
+
 mat.read<-function(file.name,ij=FALSE,sym=FALSE){
 	if(ij){
 		x<-matrix(data=scan(file.name),ncol=3,byrow=TRUE)
@@ -21,7 +21,11 @@ mat.read<-function(file.name,ij=FALSE,sym=FALSE){
 			x[,1]<-x[,1]+1
 			x[,2]<-x[,2]+1
 		}
-		mat<-matrix(data=0,nrow=max(x[,1]),ncol=max(x[,2]))
+		if(sym){
+			mat <- matrix(data = 0, nrow = max(x[,1:2]), ncol = max(x[,1:2]))
+		}else{
+			mat<-matrix(data=0,nrow=max(x[,1]),ncol=max(x[,2]))
+		}
 		for(i in 1:dim(x)[1]){
 			mat[x[i,1],x[i,2]]<-x[i,3]
 			if(sym){
@@ -32,4 +36,4 @@ mat.read<-function(file.name,ij=FALSE,sym=FALSE){
 			mat<-as.matrix(read.table(file.name))
 			}
 	return(mat)
-	} 
+	}
